function widget_pos_order(widget) {
    "use strict";

    var model = openerp;

    widget.WidgetPosOrderWidget = widget.Base.extend({
        template: 'WidgetPosOrder',

        events: {
            'click .today': 'showToday',
            'click .thisWeek': 'showThisWeek',
            'click .thisMonth': 'showThisMonth',
        },

        init: function (parent) {
            this._super(parent, {
                width: 3,
                height: 2
            });
        },

        start: function () {
            var self = this;
            self.fetchInitial();
        },

        fetchInitial: function(){
            var self = this;
            self.$el.find('#morosidad').block({
                message: null,
                overlayCSS: {
                    backgroundColor: '#FAFAFA'
                }
            });
            self.$el.find('.widget-content.widget-loading').css('display','flex');

            self.fetchPosOrder().then(function (PosOrder) {
                return PosOrder;
            }).then(function (PosOrder) {
                self.PosOrder = PosOrder;
                return self.fetchResCompany();
            }).then(function(ResCompany) {
                self.ResCompany = ResCompany;
                return self.fetchResCurrecy();
            }).then(function(ResCurrecy) {
                self.ResCurrecy = ResCurrecy;
                return self.showThisMonth();
            });
        },

        // Usuario Logeado
        fetchCurrentUser: function() {
            var self = this;
            var ResUser = new model.web.Model('res.users');
            return ResUser.call('get_user', {
                context: new model.web.CompoundContext()
            });
        },

        // Lista de Graficos disponibles para el usuario
        fetchResUser: function(id) {
            var self = this;
            var defer = $.Deferred();
            var fields = ['id','name','chart_ids'];
            var domain = [['id','=',id]];
            var ResUser = new model.web.Model('res.users');
            ResUser.query(fields).filter(domain).all().then(function (results) {
                defer.resolve(results);
            });

            return defer;
        },

        // Obtener detalles de la lista de graficos
        fetchChartList: function(chart_ids) {
            var self = this;
            var defer = $.Deferred();
            var fields = ['id','name'];
            var domain = [['id','in',chart_ids]];
            var ChartList = new model.web.Model('chart.list');
            ChartList.query(fields).filter(domain).all().then(function (results) {
                defer.resolve(results);
            });
            return defer;
        },

        fetchPosOrder: function() {
            var self = this;
            var defer = $.Deferred();
            var fields = ['id', 'name', 'date_order', 'amount_total'];
            var domain = [['state', 'not in', ['draft','cancel']]];
            var PosOrder = new model.web.Model('pos.order');
            PosOrder.query(fields).filter(domain).all().then(function(results) {
                defer.resolve(results);
            });

            return defer;
        },

        fetchResCompany: function() {
            var self = this;
            var defer = $.Deferred();
            var fields = ['id','name', 'currency_id'];
            var domain = [['id', '=', 1]];
            var ResCompany = new model.web.Model('res.company');
            ResCompany.query(fields).filter(domain).all().then(function (results) {
                defer.resolve(results);
            });

            return defer;
        },

        fetchResCurrecy : function(){
            var self = this;
            var defer = $.Deferred();
            var fields = ['id','name', 'symbol', 'rate_silent', 'base', 'decimal_separator', 'decimal_places', 'thousands_separator', 'symbol_position'];
            var domain = [['active', '=', true]];
            var ResCurrecy = new model.web.Model('res.currency');
            ResCurrecy.query(fields).filter(domain).all().then(function(results) {
                defer.resolve(results);
            });
            return defer;
        },

        getResCurrency: function (id) {
            var self = this;
            return _.filter(self.ResCurrecy,function (item) {
                return item.id === id;
            })
        },

        getTodayPosOrder:function() {
            var self = this;
            var date = moment().format('YYYY-MM-DD');
            return _.flatten(_.filter(self.PosOrder,function (inv) {
                return moment(inv.date_order).format('YYYY-MM-DD') === date;
            }));
        },

        getThisWeekPosOrder:function() {
            var self = this;
            var week = moment().week();
            return _.flatten(_.filter(self.PosOrder,function (inv) {
                return moment(inv.date_order).week() === week & moment(inv.date_order).format('YYYY')=== moment().format('YYYY');
            }));
        },

        getThisMonthPosOrder:function() {
            var self = this;
            return _.flatten(_.filter(self.PosOrder,function (inv) {
                return moment(inv.date_order).format('YYYY-MM')=== moment().format('YYYY-MM');
            }));
        },

        showToday: function () {
            var self = this;
            var amount = 0;
            var data = [];
            var pos_order = self.getTodayPosOrder();
            var CurrencyBase = self.getResCurrency(self.ResCompany[0].currency_id[0]).shift();
            if(pos_order.length > 0){
                amount = _.reduce(_.map(pos_order, function (map) {
                    return map.amount_total;
                }), function (memo, num) {
                    return memo + num;
                });
            }
            self.$el.find('.widget-content.widget-loading').css('display','none');
            self.$el.find('.widget-content').find('a').text(accounting.formatMoney(amount, CurrencyBase.symbol, CurrencyBase.decimal_places, CurrencyBase.thousands_separator, CurrencyBase.decimal_separator))
        },

        showThisWeek: function () {
            var self = this;
            var amount = 0;
            var data = [];
            var pos_order = self.getThisWeekPosOrder();
            var CurrencyBase = self.getResCurrency(self.ResCompany[0].currency_id[0]).shift();
            if(pos_order.length > 0){
                amount = _.reduce(_.map(pos_order, function (map) {
                    return map.amount_total;
                }), function (memo, num) {
                    return memo + num;
                });
            }
            self.$el.find('.widget-content.widget-loading').css('display','none');
            self.$el.find('.widget-content').find('a').text(accounting.formatMoney(amount, CurrencyBase.symbol, CurrencyBase.decimal_places, CurrencyBase.thousands_separator, CurrencyBase.decimal_separator))
        },

        showThisMonth: function () {
            var self = this;
            var amount = 0;
            var data = [];
            var pos_order = self.getThisMonthPosOrder();
            var CurrencyBase = self.getResCurrency(self.ResCompany[0].currency_id[0]).shift();
            if(pos_order.length > 0){
                amount = _.reduce(_.map(pos_order, function (map) {
                    return map.amount_total;
                }), function (memo, num) {
                    return memo + num;
                });
            }
            self.$el.find('.widget-content.widget-loading').css('display','none');
            self.$el.find('.widget-content').find('a').text(accounting.formatMoney(amount, CurrencyBase.symbol, CurrencyBase.decimal_places, CurrencyBase.thousands_separator, CurrencyBase.decimal_separator))
        },
    });
}